@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2010-2012 by Daniel Nicoletti                           *
+ *   Copyright (C) 2010-2018 by Daniel Nicoletti                           *
  *   dantti12@gmail.com                                                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -33,7 +33,6 @@
 #include <NoSelectionRectDelegate.h>
 
 #include <QItemSelectionModel>
-#include <QStringBuilder>
 #include <QDebug>
 
 // system-config-printer --setup-printer='file:/tmp/printout' --devid='MFG:Ricoh;MDL:Aficio SP C820DN'
@@ -82,6 +81,7 @@ PageDestinations::PageDestinations(const QVariantHash &args, QWidget *parent) :
     ui->stackedWidget->addWidget(m_chooseLabel);
 
     // Hide the message widget
+    ui->messageWidget->setWordWrap(true);
     ui->messageWidget->setMessageType(KMessageWidget::Error);
     ui->messageWidget->hide();
 
@@ -90,8 +90,7 @@ PageDestinations::PageDestinations(const QVariantHash &args, QWidget *parent) :
     m_model = new DevicesModel(this);
     ui->devicesTV->setModel(m_model);
     ui->devicesTV->setItemDelegate(new NoSelectionRectDelegate(this));
-    connect(ui->devicesTV->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
-            this, SLOT(deviceChanged()));
+    connect(ui->devicesTV->selectionModel(), &QItemSelectionModel::selectionChanged, this, &PageDestinations::deviceChanged);
     connect(m_model, &DevicesModel::errorMessage, ui->messageWidget, &KMessageWidget::setText);
     connect(m_model, &DevicesModel::errorMessage, ui->messageWidget, &KMessageWidget::animatedShow);
 
@@ -137,7 +136,7 @@ bool PageDestinations::isValid() const
 QVariantHash PageDestinations::values() const
 {
     QVariantHash ret = m_args;
-    GenericPage *page = qobject_cast<GenericPage*>(ui->stackedWidget->currentWidget());
+    auto page = qobject_cast<GenericPage*>(ui->stackedWidget->currentWidget());
     if (page) {
         ret = page->values();
     } else if (canProceed()) {
@@ -150,7 +149,7 @@ bool PageDestinations::canProceed() const
 {
     bool ret = ui->stackedWidget->currentIndex() != 0;
 
-    GenericPage *page = qobject_cast<GenericPage*>(ui->stackedWidget->currentWidget());
+    auto page = qobject_cast<GenericPage*>(ui->stackedWidget->currentWidget());
     if (page) {
         ret = page->canProceed();
     }
@@ -169,13 +168,14 @@ void PageDestinations::deviceChanged()
             ui->connectionsGB->setVisible(false);
         } else if (uris.type() == QVariant::StringList) {
             ui->connectionsCB->clear();
-            foreach (const QString &uri, uris.toStringList()) {
+            for (const QString &uri : uris.toStringList()) {
                 ui->connectionsCB->addItem(uriText(uri), uri);
             }
             ui->connectionsGB->setVisible(true);
         } else {
             ui->connectionsCB->clear();
-            foreach (const KCupsPrinter &printer, uris.value<KCupsPrinters>()) {
+            const auto printers = uris.value<KCupsPrinters>();
+            for (const KCupsPrinter &printer : printers) {
                 ui->connectionsCB->addItem(printer.name(), qVariantFromValue(printer));
             }
             ui->connectionsGB->setVisible(true);
@@ -302,7 +302,7 @@ QVariantHash PageDestinations::selectedItemValues() const
             QVariant aux = ui->connectionsCB->itemData(ui->connectionsCB->currentIndex());
             KCupsPrinter printer = aux.value<KCupsPrinter>();
             QUrl url(uri.toString());
-            url.setPath(QLatin1String("printers/") % printer.name());
+            url.setPath(QLatin1String("printers/") + printer.name());
             ret[KCUPS_DEVICE_URI] = url.url();
             ret[KCUPS_DEVICE_ID] = index.data(DevicesModel::DeviceId);
             ret[KCUPS_PRINTER_INFO] = printer.info();
@@ -317,7 +317,7 @@ QVariantHash PageDestinations::selectedItemValues() const
 
 void PageDestinations::setCurrentPage(QWidget *widget, const QVariantHash &args)
 {
-    GenericPage *page = qobject_cast<GenericPage*>(widget);
+    auto page = qobject_cast<GenericPage*>(widget);
     if (page) {
         page->setValues(args);
         if (ui->stackedWidget->currentWidget() != page) {;
@@ -359,7 +359,7 @@ QString PageDestinations::uriText(const QString &uri) const
         ret = i18n("AppSocket/HP JetDirect");
     } else if (uri.startsWith(QLatin1String("lpd"))) {
         // Check if the queue name is defined
-        QString queue = uri.section(QLatin1Char('/'), -1, -1);
+        const QString queue = uri.section(QLatin1Char('/'), -1, -1);
         if (queue.isEmpty()) {
             ret = i18n("LPD/LPR queue");
         } else {
@@ -369,7 +369,7 @@ QString PageDestinations::uriText(const QString &uri) const
         ret = i18n("Windows Printer via SAMBA");
     } else if (uri.startsWith(QLatin1String("ipp"))) {
         // Check if the queue name (fileName) is defined
-        QString queue = uri.section(QLatin1Char('/'), -1, -1);
+        const QString queue = uri.section(QLatin1Char('/'), -1, -1);
         if (queue.isEmpty()) {
             ret = i18n("IPP");
         } else {
@@ -399,3 +399,5 @@ QString PageDestinations::uriText(const QString &uri) const
     }
     return ret;
 }
+
+#include "moc_PageDestinations.cpp"
