@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2010-2012 Daniel Nicoletti <dantti12@gmail.com>         *
+ *   Copyright (C) 2010-2018 Daniel Nicoletti <dantti12@gmail.com>         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -36,12 +36,12 @@ ConfigurePrinterInterface::ConfigurePrinterInterface(QObject *parent) :
 {
     qCDebug(PM_CONFIGURE_PRINTER) << "Creating Helper";
     (void) new ConfigurePrinterAdaptor(this);
-    if (!QDBusConnection::sessionBus().registerService("org.kde.ConfigurePrinter")) {
+    if (!QDBusConnection::sessionBus().registerService(QLatin1String("org.kde.ConfigurePrinter"))) {
         qCDebug(PM_CONFIGURE_PRINTER) << "another helper is already running";
         return;
     }
 
-    if (!QDBusConnection::sessionBus().registerObject("/", this)) {
+    if (!QDBusConnection::sessionBus().registerObject(QLatin1String("/"), this)) {
         qCDebug(PM_CONFIGURE_PRINTER) << "unable to register service interface to dbus";
         return;
     }
@@ -62,12 +62,9 @@ void ConfigurePrinterInterface::ConfigurePrinter(const QString &destName)
         // Reserve this since the CUPS call might take a long time
         m_uis[destName] = 0;
 
-        QStringList att;
-        att << KCUPS_PRINTER_NAME;
-        att << KCUPS_PRINTER_TYPE;
         // Get destinations with these attributes
         QPointer<KCupsRequest> request = new KCupsRequest;
-        request->getPrinters(att);
+        request->getPrinters({ KCUPS_PRINTER_NAME, KCUPS_PRINTER_TYPE });
         request->waitTillFinished();
         if (!request) {
             return;
@@ -75,10 +72,10 @@ void ConfigurePrinterInterface::ConfigurePrinter(const QString &destName)
 
         bool found = false;
         KCupsPrinter printer;
-        KCupsPrinters printers = request->printers();
-        for (int i = 0; i < printers.size(); i++) {
-            if (printers.at(i).name() == destName) {
-                printer = printers.at(i);
+        const KCupsPrinters printers = request->printers();
+        for (const KCupsPrinter &p : printers) {
+            if (p.name() == destName) {
+                printer = p;
                 found = true;
                 break;
             }
@@ -86,11 +83,9 @@ void ConfigurePrinterInterface::ConfigurePrinter(const QString &destName)
         request->deleteLater();
 
         if (found) {
-            ConfigureDialog *ui = new ConfigureDialog(printer.name(), printer.isClass());
-            connect(m_updateUi, SIGNAL(timeout()),
-                    ui, SLOT(update()));
-            connect(ui, SIGNAL(finished(int)),
-                    this, SLOT(RemovePrinter()));
+            auto ui = new ConfigureDialog(printer.name(), printer.isClass());
+            connect(m_updateUi, &QTimer::timeout, ui, static_cast<void(ConfigureDialog::*)()>(&ConfigureDialog::update));
+            connect(ui, &ConfigureDialog::finished, this, &ConfigurePrinterInterface::RemovePrinter);
             ui->show();
             m_uis[printer.name()] = ui;
         } else {
@@ -114,7 +109,7 @@ void ConfigurePrinterInterface::ConfigurePrinter(const QString &destName)
 
 void ConfigurePrinterInterface::RemovePrinter()
 {
-    QWidget *ui = qobject_cast<QWidget*>(sender());
+    auto ui = qobject_cast<QWidget*>(sender());
     if (ui) {
         m_uis.remove(m_uis.key(ui));
     }
@@ -125,3 +120,5 @@ void ConfigurePrinterInterface::RemovePrinter()
          emit quit();
     }
 }
+
+#include "moc_ConfigurePrinterInterface.cpp"
